@@ -1,5 +1,5 @@
 /* sleep - delay for a specified amount of time.
-   Copyright (C) 84, 91, 92, 93, 1994 Free Software Foundation, Inc.
+   Copyright (C) 84, 91, 92, 93, 94, 95, 1996 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -12,38 +12,26 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
-#ifdef HAVE_CONFIG_H
-#if defined (CONFIG_BROKETS)
-/* We use <config.h> instead of "config.h" so that a compilation
-   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
-   (which it would do because it found this file in $srcdir).  */
 #include <config.h>
-#else
-#include "config.h"
-#endif
-#endif
-
 #include <stdio.h>
 #include <sys/types.h>
 #include <getopt.h>
 
-#include "version.h"
 #include "system.h"
+#include "error.h"
 
-void error ();
-
-static long argdecode ();
+static long argdecode __P ((const char *s));
 
 /* The name by which this program was run. */
 char *program_name;
 
-/* If non-zero, display usage information and exit.  */
+/* If nonzero, display usage information and exit.  */
 static int show_help;
 
-/* If non-zero, print the version on standard output and exit.  */
+/* If nonzero, print the version on standard output and exit.  */
 static int show_version;
 
 static struct option const long_options[] =
@@ -54,36 +42,36 @@ static struct option const long_options[] =
 };
 
 static void
-usage (status)
-     int status;
+usage (int status)
 {
   if (status != 0)
-    fprintf (stderr, "Try `%s --help' for more information.\n",
+    fprintf (stderr, _("Try `%s --help' for more information.\n"),
 	     program_name);
   else
     {
-      printf ("Usage: %s [OPTION]... NUMBER[SUFFIX]\n", program_name);
-      printf ("\
+      printf (_("Usage: %s [OPTION]... NUMBER[SUFFIX]\n"), program_name);
+      printf (_("\
+Pause for NUMBER seconds.\n\
+SUFFIX may be s to keep seconds, m for minutes, h for hours or d for days.\n\
 \n\
   --help      display this help and exit\n\
-  --version   output version information and exit\n\
-\n\
-SUFFIX may be s for seconds, m for minutes, h for hours or d for days.\n\
-");
+  --version   output version information and exit\n"));
+      puts (_("\nReport bugs to sh-utils-bugs@gnu.ai.mit.edu"));
     }
   exit (status);
 }
 
-void
-main (argc, argv)
-     int argc;
-     char **argv;
+int
+main (int argc, char **argv)
 {
   int i;
   unsigned seconds = 0;
   int c;
 
   program_name = argv[0];
+  setlocale (LC_ALL, "");
+  bindtextdomain (PACKAGE, LOCALEDIR);
+  textdomain (PACKAGE);
 
   while ((c = getopt_long (argc, argv, "", long_options, (int *) 0)) != EOF)
     {
@@ -99,7 +87,7 @@ main (argc, argv)
 
   if (show_version)
     {
-      printf ("%s\n", version_string);
+      printf ("sleep (%s) %s\n", GNU_PACKAGE, VERSION);
       exit (0);
     }
 
@@ -108,8 +96,8 @@ main (argc, argv)
 
   if (argc == 1)
     {
-      fprintf (stderr, "Usage: %s number[smhd]...\n", argv[0]);
-      exit (1);
+      error (0, 0, _("too few arguments"));
+      usage (1);
     }
 
   for (i = 1; i < argc; i++)
@@ -121,11 +109,10 @@ main (argc, argv)
 }
 
 static long
-argdecode (s)
-     char *s;
+argdecode (const char *s)
 {
   long value;
-  register char *p = s;
+  register const char *p = s;
   register char c;
 
   value = 0;
@@ -150,6 +137,6 @@ argdecode (s)
     }
 
   if (*p)
-    error (1, 0, "invalid time interval `%s'", s);
+    error (1, 0, _("invalid time interval `%s'"), s);
   return value;
 }
